/*
** GENERAL.H
**
**      This header file contains the public HTTP interfaces used by the
**		Sambar Server for interfacing with General RCP and Scalar
**		Utility functions.
**
**		Confidential Property of Tod Sambar
**		(c) Copyright Tod Sambar 1997
**		All rights reserved.
**
**
** History:
** Chg#	Date	Description												Resp
** ----	-------	-------------------------------------------------------	----
**		10JUN97	Created													sambar
*/

#if     !defined(__GENERAL_H__)
#define __GENERAL_H__

#include	<sambar.h>
#ifdef	WIN32
#include	<io.h>
#include	<sys/stat.h>
#include	<sys/locking.h>
#include	<share.h>
#include	<fcntl.h>
#endif	/* WIN32 */

/*
** General Defines
*/
#define INT_WIDTH		7		/* MAX is 8 */
#define COUNT_WIDTH 	8
#define COUNT_HEIGHT	16

static char           *bitmap[] = 
{
    "0xff", "0xff", "0xff", "0xc3", "0x99", "0x99", "0x99", "0x99",	/* rows 1-8  of 0 */
    "0x99", "0x99", "0x99", "0x99", "0xc3", "0xff", "0xff", "0xff",	/* rows 9-16 of 0 */
    "0xff", "0xff", "0xff", "0xcf", "0xc7", "0xcf", "0xcf", "0xcf",	/* rows 1-8  of 1 */
    "0xcf", "0xcf", "0xcf", "0xcf", "0xcf", "0xff", "0xff", "0xff",	/* rows 9-16 of 1 */
    "0xff", "0xff", "0xff", "0xc3", "0x99", "0x9f", "0x9f", "0xcf",	/* rows 1-8  of 2 */
    "0xe7", "0xf3", "0xf9", "0xf9", "0x81", "0xff", "0xff", "0xff",	/* rows 9-16 of 2 */
    "0xff", "0xff", "0xff", "0xc3", "0x99", "0x9f", "0x9f", "0xc7",	/* rows 1-8  of 3 */
    "0x9f", "0x9f", "0x9f", "0x99", "0xc3", "0xff", "0xff", "0xff",	/* rows 9-16 of 3 */
    "0xff", "0xff", "0xff", "0xcf", "0xcf", "0xc7", "0xc7", "0xcb",	/* rows 1-8  of 4 */
    "0xcb", "0xcd", "0x81", "0xcf", "0x87", "0xff", "0xff", "0xff",	/* rows 9-16 of 4 */
    "0xff", "0xff", "0xff", "0x81", "0xf9", "0xf9", "0xf9", "0xc1",	/* rows 1-8  of 5 */
    "0x9f", "0x9f", "0x9f", "0x99", "0xc3", "0xff", "0xff", "0xff",	/* rows 9-16 of 5 */
    "0xff", "0xff", "0xff", "0xc7", "0xf3", "0xf9", "0xf9", "0xc1",	/* rows 1-8  of 6 */
    "0x99", "0x99", "0x99", "0x99", "0xc3", "0xff", "0xff", "0xff",	/* rows 9-16 of 6 */
    "0xff", "0xff", "0xff", "0x81", "0x99", "0x9f", "0x9f", "0xcf",	/* rows 1-8  of 7 */
    "0xcf", "0xe7", "0xe7", "0xf3", "0xf3", "0xff", "0xff", "0xff",	/* rows 9-16 of 7 */
    "0xff", "0xff", "0xff", "0xc3", "0x99", "0x99", "0x99", "0xc3",	/* rows 1-8  of 8 */
    "0x99", "0x99", "0x99", "0x99", "0xc3", "0xff", "0xff", "0xff",	/* rows 9-16 of 8 */
    "0xff", "0xff", "0xff", "0xc3", "0x99", "0x99", "0x99", "0x99",	/* rows 1-8  of 9 */
    "0x83", "0x9f", "0x9f", "0xcf", "0xe3", "0xff", "0xff", "0xff"	/* rows 9-16 of 9 */
};

static unsigned char	bitmap2[11][COUNT_HEIGHT] =
{
	{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3C, 0x66, 0xC3, 0xC3,
		0xDB, 0xDB, 0xC3, 0xC3, 0x66, 0x3C }, /* 0 */
	{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x1C, 0x1E, 0x18,
		0x18, 0x18, 0x18, 0x18, 0x18, 0x7E }, /* 1 */
	{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3E, 0x63, 0x60, 0x30,
		0x18, 0x0C, 0x06, 0x03, 0x63, 0x7F }, /* 2 */
	{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3E, 0x63, 0x60, 0x60,
		0x3C, 0x60, 0x60, 0x60, 0x63, 0x3E }, /* 3 */
	{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x38, 0x3C, 0x36,
		0x33, 0x7F, 0x30, 0x30, 0x30, 0x78 }, /* 4 */
	{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7F, 0x03, 0x03, 0x03,
		0x3F, 0x60, 0x60, 0x60, 0x63, 0x3E }, /* 5 */
	{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1C, 0x06, 0x03, 0x03,
		0x3F, 0x63, 0x63, 0x63, 0x63, 0x3E }, /* 6 */
	{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7F, 0x63, 0x60, 0x60,
		0x30, 0x18, 0x0C, 0x0C, 0x0C, 0x0C }, /* 7 */
	{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3E, 0x63, 0x63, 0x63,
		0x3E, 0x63, 0x63, 0x63, 0x63, 0x3E }, /* 8 */
	{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3E, 0x63, 0x63, 0x63,
		0x7E, 0x60, 0x60, 0x60, 0x30, 0x1E }, /* 9 */
	{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x18,
		0x00, 0x00, 0x00, 0x18, 0x18, 0x00 }  /* : */
};

/*
** Sambar Server General Utility DLL Function Prototypes
*/
#if defined(__cplusplus)
extern "C" {
#endif /* defined(__cplusplus) */

extern SA_RETCODE SA_EXPORT		general_init(SA_CTX *sactx);

extern SA_RETCODE SA_PUBLIC		pagecount_rpc(SA_CTX *sactx, SA_CONN *saconn,
									SA_PARAMS *saparams, SA_INT *infop);
extern SA_RETCODE SA_PUBLIC		pagecount_scalar(SA_CTX *sactx, SA_CONN *saconn,
									SA_ARG *saargs, SA_CHAR *value);

#if defined(__cplusplus)
}
#endif /* defined(__cplusplus) */

#endif /* __GENERAL_H__ */
